@@ -19,17 +19,28 @@
 #include <uuid/uuid.h>
 #include <stdint.h>
 
-#define DBI_VERSION      0.5.6
+#define DBI_VERSION      0.6.0
 
 namespace dbi {
     struct null {};
     struct execute {};
 }
 
+namespace dbi {
+    typedef std::vector<int> int_list_t;
+    typedef std::vector<std::string> string_list_t;
+}
+
 #include "dbic++/error.h"
 #include "dbic++/param.h"
+namespace dbi {
+    typedef std::vector<dbi::Param> param_list_t;
+}
+
 #include "dbic++/container.h"
-#include "dbic++/cpool.h"
+namespace dbi {
+    typedef dbi::FieldSet field_list_t;
+}
 
 #define DEFAULT_DRIVER_PATH "/usr/local/lib/dbic++"
 
@@ -63,6 +74,6 @@ namespace dbi {
 #include "dbic++/statement.h"
 #include "dbic++/result.h"
 #include "dbic++/query.h"
-#include "dbic++/socketinfo.h"
+#include "dbic++/etc.h"
 
 #endif
