@@ -1,3 +1,4 @@
+#pragma once
 #ifndef _DBICXX_CONTAINER_H
 #define _DBICXX_CONTAINER_H
 
@@ -6,5 +7,6 @@
 
 #include "result_row.h"
 #include "result_row_hash.h"
+#include "field_set.h"
 
 #endif
