@@ -1,7 +1,6 @@
-namespace dbi {
+#pragma once
 
-    using namespace std;
-    using namespace pcrecpp;
+namespace dbi {
 
     class Result;
     class Statement;
@@ -43,20 +42,36 @@ namespace dbi {
     */
     class Handle {
         protected:
-        vector<string> trx;
+        string_list_t trx;
         AbstractHandle *h;
         public:
         /*
-            Constructor: Handle(string, string, string, string, string, string)
+            Constructor: Handle(string, string, string, string, string, string, char*)
             Parameters:
-                driver - driver name (postgresql, mysql, etc.)
-                user   - database user name
-                pass   - database password, can be empty string.
-                dbname - database name.
-                host   - host name or ip address (socket based connections are not supported at this time).
-                port   - port number as a string.
+                driver  - driver name (postgresql, mysql, etc.)
+                user    - database user name
+                pass    - database password, can be empty string.
+                dbname  - database name.
+                host    - host name or ip address (socket based connections are not supported at this time).
+                port    - port number as a string.
+                options - driver specific options as a string, only ssl specific options are supported at present.
+                  e.g.
+                    "sslca=$HOME/certs/ca-cert.pem"
+                    "sslcert=$HOME/certs/client-cert.pem;sslkey=$HOME/certs/client-key.pem"
+
+                  The mysql driver supports the following settings at present,
+                    sslca, sslcert, sslkey, sslcapath, sslcipher
+
+                  The postgresql driver can be set to use client certificates using the following settings,
+                    sslcert, sslkey
+
+                  sqlite3 driver ignores these options currently.
+
+
+
         */
-        Handle(string driver, string user, string pass, string dbname, string host, string port);
+        Handle(std::string driver, std::string user, std::string pass, std::string dbname,
+               std::string host, std::string port, char *options = 0);
 
         /*
             Constructor: Handle(string, string, string, string)
@@ -68,7 +83,7 @@ namespace dbi {
 
             This assumes localhost and default port number for the database.
         */
-        Handle(string driver, string user, string pass, string dbname);
+        Handle(std::string driver, std::string user, std::string pass, std::string dbname);
 
         /*
             Constructor: Handle(AbstractHandle*)
@@ -94,13 +109,19 @@ namespace dbi {
             Function: execute(string)
             See <AbstractHandle::execute(string)>
         */
-        uint32_t execute(string sql);
+        uint32_t execute(std::string sql);
 
         /*
-            Function: execute(string, vector<Param>&)
-            See <AbstractHandle::execute(string, vector<Param>&)>
+            Function: execute(string, param_list_t&)
+            See <AbstractHandle::execute(string, param_list_t&)>
         */
-        uint32_t execute(string sql, vector<Param> &bind);
+        uint32_t execute(std::string sql, param_list_t &bind);
+
+
+        Result* aexecute(std::string sql);
+        Result* aexecute(std::string sql, param_list_t &bind);
+
+        int socket();
 
         /*
             Function: result
@@ -122,7 +143,7 @@ namespace dbi {
             Returns:
             A pointer to Statement.
         */
-        Statement* prepare(string sql);
+        Statement* prepare(std::string sql);
 
         /*
             Operator: <<(string)
@@ -134,7 +155,7 @@ namespace dbi {
             Returns:
             A pointer to Statement.
         */
-        Statement* operator<<(string sql);
+        Statement* operator<<(std::string sql);
 
         /*
             Function: begin
@@ -158,19 +179,19 @@ namespace dbi {
             Function: begin(string)
             See <AbstractHandle::begin(string)>
         */
-        bool begin(string name)
+        bool begin(std::string name)
 ;
         /*
             Function: commit(string)
             See <AbstractHandle::commit(string)>
         */
-        bool commit(string name);
+        bool commit(std::string name);
 
         /*
             Function: rollback(string)
             See <AbstractHandle::rollback(string)>
         */
-        bool rollback(string name);
+        bool rollback(std::string name);
 
         /*
             Function: close
@@ -188,13 +209,13 @@ namespace dbi {
             Returns:
             list of transactions.
         */
-        vector<string>& transactions();
+        string_list_t& transactions();
 
         /*
             Function: write(string, FieldSet&, IO*)
             See <AbstractHandle::write(string, FieldSet&, IO*)>
         */
-        uint64_t write(string table, FieldSet &fields, IO*);
+        uint64_t write(std::string table, field_list_t &fields, IO*);
 
         /*
             Function: setTimeZoneOffset(int, int)
@@ -212,7 +233,7 @@ namespace dbi {
             Function: escape(string)
             See <AbstractHandle::escape(string)>
         */
-        string escape(string);
+        string escape(std::string);
 
         /*
             Function: driver
