@@ -1,10 +1,9 @@
+#pragma once
 #ifndef _DBICXX_RESULTROW_HASH_H
 #define _DBICXX_RESULTROW_HASH_H
 
 namespace dbi {
 
-    using namespace std;
-
     /*
         Class: ResultRowHash
         Encapsulates a hash that maps field names to values in a result.
@@ -19,9 +18,9 @@ namespace dbi {
             Returns the fields in the result.
 
             Returns:
-            fields - vector<string>
+            fields - string_list_t
         */
-        vector<string> fields();
+        string_list_t fields();
         operator bool() { return data.size() > 0; }
         /*
             Operator: [](const char*)
@@ -38,9 +37,9 @@ namespace dbi {
             Returns:
             value - Param
         */
-        Param& operator [](string&);
+        Param& operator [](std::string&);
         void clear();
-        friend ostream& operator<< (ostream &out, ResultRowHash &r);
+        friend std::ostream& operator<< (std::ostream &out, ResultRowHash &r);
     };
 }
 
