@@ -1,5 +1,9 @@
+#pragma once
+
 namespace dbi {
 
+    class AbstractHandle;
+
     /*
         Section: Utility functions
     */
@@ -10,7 +14,7 @@ namespace dbi {
         string name;
         string version;
         void *handle;
-        AbstractHandle* (*connect)(string user, string pass, string dbname, string host, string port);
+        AbstractHandle* (*connect)(string user, string pass, string dbname, string host, string port, char *);
     };
 
     bool dbiInitialize(string path = DEFAULT_DRIVER_PATH);
@@ -38,7 +42,7 @@ namespace dbi {
     void trace(bool flag, int fd);
 
     void logMessage(int fd, string msg);
-    string formatParams(string sql, vector<Param> &p);
+    string formatParams(string sql, param_list_t &p);
 
     string generateCompactUUID();
 }
